@@ -1,11 +1,11 @@
 /*
  *
- *  This file is part of MUMPS 5.1.1, released
- *  on Mon Mar 20 14:34:33 UTC 2017
+ *  This file is part of MUMPS 5.2.1, released
+ *  on Fri Jun 14 14:46:05 UTC 2019
  *
  *
- *  Copyright 1991-2017 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
- *  University of Bordeaux.
+ *  Copyright 1991-2019 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
  *  released under the CeCILL-C license:
@@ -42,7 +42,7 @@ MUMPS_LOW_LEVEL_INIT_ERR_STR(MUMPS_INT *dim, char* err_str, mumps_ftnlen l1){
 }
 #if ! defined(MUMPS_WIN32) && ! defined(WITHOUT_PTHREAD)
 MUMPS_INLINE MUMPS_INT
-mumps_io_protect_err()
+mumps_io_protect_err(void)
 {
   if(mumps_io_flag_async==IO_ASYNC_TH){
     pthread_mutex_lock(&err_mutex);
@@ -50,7 +50,7 @@ mumps_io_protect_err()
   return 0;
 }
 MUMPS_INLINE MUMPS_INT
-mumps_io_unprotect_err()
+mumps_io_unprotect_err(void)
 {
   if(mumps_io_flag_async==IO_ASYNC_TH){
     pthread_mutex_unlock(&err_mutex);
@@ -58,19 +58,19 @@ mumps_io_unprotect_err()
   return 0;
 }
 MUMPS_INT
-mumps_io_init_err_lock()
+mumps_io_init_err_lock(void)
 {
   pthread_mutex_init(&err_mutex,NULL);
   return 0;
 }
 MUMPS_INT
-mumps_io_destroy_err_lock()
+mumps_io_destroy_err_lock(void)
 {
   pthread_mutex_destroy(&err_mutex);
   return 0;
 }
 MUMPS_INT
-mumps_check_error_th()
+mumps_check_error_th(void)
 {
   /* If err_flag != 0, then error_str is set */
   return err_flag;
